==> shinken-enterprise_V02.08.01.01_ALL-LANG_Windows-poller-only_FULL_2022-11-17.tar.gz: shinken-enterprise_V02.08.01.01_ALL-LANG_Windows-poller-only_FULL_2022-11-17/shinkensolutions/common_ui/htdocs/js/shinken-test-auto/property/shinken-auto-test-tools-property-string.js <==
SHINKEN.TOOLS.TEST_AUTO_PROPERTY_STRING_INPUT = (function ( self ) {
    self.DOM                               = {};
    self.TEST                              = {};
    self.INTERACTION                       = {};
    //********************************************  GET DOM ELEMENT   ****************************************//
    self.DOM.mainInput                     = function ( property_name ) {
        return SHINKEN.TOOLS.TEST_AUTO_PROPERTY.DOM.line( property_name ).querySelector( '.shinken-prop-cell-action .shinken-input' );
    };
    //********************************************  TEST   **************************************************//
    self.TEST.validMainInput               = function ( timeout, property_name, styles ) {
        setTimeout( function () {
            var _input = self.DOM.mainInput( property_name );
            for ( var i = 0, _size_i = styles.length; i < _size_i; i++ ) {
                SHINKEN.TOOLS.TEST_AUTO.__hasStyle( _input, styles[ i ][ 0 ], styles[ i ][ 1 ] );
            }
        }, timeout );
        return 100;
    };
    self.TEST.validMainInputContentDisplay = function ( timeout, property_name, value_expected ) {
        setTimeout( function () {
            var _input = self.DOM.mainInput( property_name );
            SHINKEN.TOOLS.TEST_AUTO.___isEqualsTo( _input.value, value_expected, property_name + ": validMainInputContentDisplay ->" );
        }, timeout );
        return 100;
    };
    self.TEST.placeholder                  = function ( timeout, property_name, text_expected ) {
        setTimeout( function () {
            var _input = self.DOM.mainInput( property_name );
            SHINKEN.TOOLS.TEST_AUTO.___isEqualsTo( _input.placeholder, text_expected, property_name + ": placeholderContent -> " );
        }, timeout );
        return 50;
    };
    //********************************************  TEST USER   **************************************************//
    self.INTERACTION.validUserInteraction  = function ( timeout, property_name ) {
        if ( __version_shinken === "V02.07.06" ){
            return 0
        }
        var _to_return = 50;
        var _dom_input = self.DOM.mainInput( property_name );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( timeout + _to_return, _dom_input, "Main Input" + property_name );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_PROPERTY.TEST.isState( timeout + _to_return, property_name, PROPERTY.CONST.STATE_PROPERTY.INHERITANCE );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_DOM.setValue( timeout + _to_return, _dom_input, "test_auto" );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_PROPERTY.TEST.isState( timeout + _to_return, property_name, PROPERTY.CONST.STATE_PROPERTY.USER_SET );
        return _to_return;
    };
    return self;
})( SHINKEN.TOOLS.TEST_AUTO_PROPERTY_STRING_INPUT || {} );

==> shinken-enterprise_V02.08.01.06_ALL-LANG_Windows-poller-only_FULL_2023-08-18.tar.gz: shinken-enterprise_V02.08.01.06_ALL-LANG_Windows-poller-only_FULL_2023-08-18/shinkensolutions/common_ui/htdocs/js/shinken-test-auto/property/shinken-auto-test-tools-property-string.js <==
SHINKEN.TOOLS.TEST_AUTO_PROPERTY_STRING_INPUT = (function ( self ) {
    self.DOM                               = {};
    self.TEST                              = {};
    self.INTERACTION                       = {};
    //********************************************  GET DOM ELEMENT   ****************************************//
    self.DOM.mainInput                     = function ( property_name ) {
        return SHINKEN.TOOLS.TEST_AUTO_PROPERTY.DOM.line( property_name ).querySelector( '.shinken-prop-cell-action .shinken-input' );
    };
    //********************************************  TEST   **************************************************//
    self.TEST.validMainInput               = function ( timeout, property_name, styles ) {
        setTimeout( function () {
            var _input = self.DOM.mainInput( property_name );
            for ( var i = 0, _size_i = styles.length; i < _size_i; i++ ) {
                SHINKEN.TOOLS.TEST_AUTO.__hasStyle( _input, styles[ i ][ 0 ], styles[ i ][ 1 ] );
            }
        }, timeout );
        return 100;
    };
    self.TEST.validMainInputContentDisplay = function ( timeout, property_name, value_expected ) {
        setTimeout( function () {
            var _input = self.DOM.mainInput( property_name );
            SHINKEN.TOOLS.TEST_AUTO.___isEqualsTo( _input.value, value_expected, property_name + ": validMainInputContentDisplay ->" );
        }, timeout );
        return 100;
    };
    self.TEST.placeholder                  = function ( timeout, property_name, text_expected ) {
        setTimeout( function () {
            var _input = self.DOM.mainInput( property_name );
            SHINKEN.TOOLS.TEST_AUTO.___isEqualsTo( _input.placeholder, text_expected, property_name + ": placeholderContent -> " );
        }, timeout );
        return 50;
    };
    //********************************************  TEST USER   **************************************************//
    self.INTERACTION.validUserInteraction  = function ( timeout, property_name ) {
        if ( __version_shinken === SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.ALPHA ){
            return 0
        }
        var _to_return = 50;
        var _dom_input = self.DOM.mainInput( property_name );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_DOM.isVisible( timeout + _to_return, _dom_input, "Main Input" + property_name );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_PROPERTY.TEST.isState( timeout + _to_return, property_name, PROPERTY.CONST.STATE_PROPERTY.INHERITANCE );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_DOM.setValue( timeout + _to_return, _dom_input, "test_auto" );
        _to_return += SHINKEN.TOOLS.TEST_AUTO_PROPERTY.TEST.isState( timeout + _to_return, property_name, PROPERTY.CONST.STATE_PROPERTY.USER_SET );
        return _to_return;
    };
    return self;
})( SHINKEN.TOOLS.TEST_AUTO_PROPERTY_STRING_INPUT || {} );
